var class_ogre_1_1_terrain =
[
    [ "DefaultGpuBufferAllocator", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator.html", "class_ogre_1_1_terrain_1_1_default_gpu_buffer_allocator" ],
    [ "GpuBufferAllocator", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator.html", "class_ogre_1_1_terrain_1_1_gpu_buffer_allocator" ],
    [ "ImportData", "struct_ogre_1_1_terrain_1_1_import_data.html", "struct_ogre_1_1_terrain_1_1_import_data" ],
    [ "LayerInstance", "struct_ogre_1_1_terrain_1_1_layer_instance.html", "struct_ogre_1_1_terrain_1_1_layer_instance" ],
    [ "RealVector", "class_ogre_1_1_terrain.html#a8e3b80784aa7c62ca578c2f8e2a01c7c", null ],
    [ "LayerInstanceList", "class_ogre_1_1_terrain.html#a58751c7f151873a6e5cf03f59aa9ec47", null ],
    [ "Alignment", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91", [
      [ "ALIGN_X_Z", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91ac4699c4f99bea344a309d5544b33c140", null ],
      [ "ALIGN_X_Y", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91adfc96b5a388b3e48709d56b899098508", null ],
      [ "ALIGN_Y_Z", "class_ogre_1_1_terrain.html#aca4fcebfb7ed4684682347d325477e91add646ddae48fd0c7cc9c0a74458feb42", null ]
    ] ],
    [ "NeighbourIndex", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2", [
      [ "NEIGHBOUR_EAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a88c6e2c93031bba254272861a1664cc3", null ],
      [ "NEIGHBOUR_NORTHEAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2aed82e8f7f45fcb5faeef6158c9d1ff3a", null ],
      [ "NEIGHBOUR_NORTH", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a07b3c537d34f5c7e1e3e79634dfcac1d", null ],
      [ "NEIGHBOUR_NORTHWEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a8795dff5bfc2240747ee0a843a900c71", null ],
      [ "NEIGHBOUR_WEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a3a45b8d00d2ba435e61cdc99c94b0a91", null ],
      [ "NEIGHBOUR_SOUTHWEST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2aec43a04404ef9873e7d43c094e097e40", null ],
      [ "NEIGHBOUR_SOUTH", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a8c91ce1d5f82d7525102bc91fde0df2d", null ],
      [ "NEIGHBOUR_SOUTHEAST", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a4183a4a8b0f78832395fa0aa981f07bf", null ],
      [ "NEIGHBOUR_COUNT", "class_ogre_1_1_terrain.html#a2d0c6e14298e6a196148388ca2ffa9e2a5ba448a51833e6c8eea28884a706834c", null ]
    ] ],
    [ "Space", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781", [
      [ "WORLD_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a0a7049246e4a77e37dcea36fd35c4daf", null ],
      [ "LOCAL_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781ae3eabb53019f0d4ecfbff1d9a417d907", null ],
      [ "TERRAIN_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a0ad91edc61b2fb7ebe1966fc167ffe6d", null ],
      [ "POINT_SPACE", "class_ogre_1_1_terrain.html#aebf8a7aadb5de3a0669d41acfd58d781a748f0b5f2b54c63be96965de53931de6", null ]
    ] ],
    [ "Terrain", "class_ogre_1_1_terrain.html#a9cc3d8901c73b6d2b6e1613a22636801", null ],
    [ "~Terrain", "class_ogre_1_1_terrain.html#ad3516cbdabc73135b79f1d34ffda7f01", null ],
    [ "getSceneManager", "class_ogre_1_1_terrain.html#a29b325c5180def04910d06b32fe004e0", null ],
    [ "setGpuBufferAllocator", "class_ogre_1_1_terrain.html#afd269cb7c490b88d1aea4fccb4ac2451", null ],
    [ "getGpuBufferAllocator", "class_ogre_1_1_terrain.html#af1d8194d298ceec5609a7d1485bff7ca", null ],
    [ "_getNumIndexesForBatchSize", "class_ogre_1_1_terrain.html#a72c79185cbbc50e1ff016946ae14dca2", null ],
    [ "_populateIndexBuffer", "class_ogre_1_1_terrain.html#af01e8cc2a2055e30420f626269f3f38d", null ],
    [ "_calcSkirtVertexIndex", "class_ogre_1_1_terrain.html#a2ba2f7a6eb2c9356d6bddaf30fe72257", null ],
    [ "convertPosition", "class_ogre_1_1_terrain.html#a6ad6246dddf231e761c52af18397369f", null ],
    [ "convertPosition", "class_ogre_1_1_terrain.html#a09f6174d11a0339d9ff44775d48dee09", null ],
    [ "convertDirection", "class_ogre_1_1_terrain.html#a6a94314390459778b11cb4785dbd41ca", null ],
    [ "convertDirection", "class_ogre_1_1_terrain.html#a33bb06af72903323c8b8daa67c17abd7", null ],
    [ "setResourceGroup", "class_ogre_1_1_terrain.html#aacd2dcc94afbc3e8fbca6d6de1baedab", null ],
    [ "getResourceGroup", "class_ogre_1_1_terrain.html#afc98c5e76b60ff1b5bc1024a600e26cb", null ],
    [ "_getDerivedResourceGroup", "class_ogre_1_1_terrain.html#a55793a71b2ea6ed68fd04c45dfe63ed5", null ],
    [ "save", "class_ogre_1_1_terrain.html#accbc5c9286d1a898653c1b27e04f6099", null ],
    [ "save", "class_ogre_1_1_terrain.html#afce38d08848608e3bf4642678e289181", null ],
    [ "prepare", "class_ogre_1_1_terrain.html#aaf6c29ba4225758313190a53bb12e60c", null ],
    [ "prepare", "class_ogre_1_1_terrain.html#a2f08575d471649617945b200154478c5", null ],
    [ "prepare", "class_ogre_1_1_terrain.html#a20d7b036e25805405d3140b3751ec4b6", null ],
    [ "prepare", "class_ogre_1_1_terrain.html#a2b61cedddcd4ebe3b6c27068e2624d74", null ],
    [ "load", "class_ogre_1_1_terrain.html#ae7381fe2e7ea64304f59e7f10b6c90ec", null ],
    [ "load", "class_ogre_1_1_terrain.html#ae3fc60c0f8350b4872323ddf258d922d", null ],
    [ "load", "class_ogre_1_1_terrain.html#a78949cbc0a2a6d717b4606043b46d5c7", null ],
    [ "isLoaded", "class_ogre_1_1_terrain.html#af0c198af3449240a57dc63380e38a9fe", null ],
    [ "isModified", "class_ogre_1_1_terrain.html#ac09cc65643825f293320058bc6ed07ab", null ],
    [ "isHeightDataModified", "class_ogre_1_1_terrain.html#a0f29e0c116626bcb1bdb45835e0752cc", null ],
    [ "unload", "class_ogre_1_1_terrain.html#acee00b1d1d1d46633cd88b3b49f488cf", null ],
    [ "unprepare", "class_ogre_1_1_terrain.html#aa67c987848bb325bc3aef2b0ad7a9adf", null ],
    [ "getHeightData", "class_ogre_1_1_terrain.html#adc1a1c0afad76fb2de52058e23ffebc2", null ],
    [ "getHeightData", "class_ogre_1_1_terrain.html#a0457855b262d6491693709aecc661c07", null ],
    [ "getHeightAtPoint", "class_ogre_1_1_terrain.html#ac329134ec2c2ff88fa05dcb9ff1a2821", null ],
    [ "setHeightAtPoint", "class_ogre_1_1_terrain.html#a51979e546b48f5f6cc1676bc45e62007", null ],
    [ "getHeightAtTerrainPosition", "class_ogre_1_1_terrain.html#ae50846c3688082ececfe0d56ed78c792", null ],
    [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain.html#a7719018dcfb417865f00ddeef7b0951b", null ],
    [ "getHeightAtWorldPosition", "class_ogre_1_1_terrain.html#ad365d761359884e56a7c0164086a57d9", null ],
    [ "getDeltaData", "class_ogre_1_1_terrain.html#a957880834cd9bd2b4ecb0aec124d838a", null ],
    [ "getDeltaData", "class_ogre_1_1_terrain.html#acf60757185ccbb975ae6fcec74143015", null ],
    [ "getPoint", "class_ogre_1_1_terrain.html#a6999afcf4ddfa84fbd291d0d1e3bc7f7", null ],
    [ "getPointFromSelfOrNeighbour", "class_ogre_1_1_terrain.html#ad0faeda25da323eaf9d8a2a8cab3cdf1", null ],
    [ "getPoint", "class_ogre_1_1_terrain.html#ace4a475574f656cc941df6af61968c83", null ],
    [ "getPointTransform", "class_ogre_1_1_terrain.html#a909f82eee09876149fdd36a49fb5858a", null ],
    [ "getTerrainVector", "class_ogre_1_1_terrain.html#a61849058085ae7cb6c0e16bb5c21cb03", null ],
    [ "getTerrainVector", "class_ogre_1_1_terrain.html#abb4ffa0b942aca1273cc6af52c2f2b81", null ],
    [ "getTerrainVectorAlign", "class_ogre_1_1_terrain.html#aad404a040c30d1138b406cff801e1b56", null ],
    [ "getTerrainVectorAlign", "class_ogre_1_1_terrain.html#af37504438f3cca3341419bbf43b28331", null ],
    [ "getVector", "class_ogre_1_1_terrain.html#a9831992c806d7b12114acdf35fc40aff", null ],
    [ "getVector", "class_ogre_1_1_terrain.html#af8cafe25232ec796bdb2ae229de6d590", null ],
    [ "getVectorAlign", "class_ogre_1_1_terrain.html#a00dd54e0cf38fac3e729bf481761a672", null ],
    [ "getVectorAlign", "class_ogre_1_1_terrain.html#a539d01d15e180e7c67727884badd5b7d", null ],
    [ "getPosition", "class_ogre_1_1_terrain.html#a19d92cbdb6f2dc3ff5bc8e57ee3df8dc", null ],
    [ "getPosition", "class_ogre_1_1_terrain.html#a4f12c4926b592f118508ee06b84eb220", null ],
    [ "getTerrainPosition", "class_ogre_1_1_terrain.html#aac94de7f1d8908a2adc0432b05804a00", null ],
    [ "getTerrainPosition", "class_ogre_1_1_terrain.html#a7db38251c418f66b2615037babfe781d", null ],
    [ "getPositionAlign", "class_ogre_1_1_terrain.html#af6b0f1642a0f159d6000594ccf006736", null ],
    [ "getPositionAlign", "class_ogre_1_1_terrain.html#a6f04aa8304bb033f4d33b64e08f05410", null ],
    [ "getTerrainPositionAlign", "class_ogre_1_1_terrain.html#a3fb22ca5067bb7f2b5b6d29f6e64a2b0", null ],
    [ "getTerrainPositionAlign", "class_ogre_1_1_terrain.html#a1b38900f2914d915b54dc3ce1d37eb40", null ],
    [ "getAlignment", "class_ogre_1_1_terrain.html#a7b0821197e537ceeff981835c0c127e2", null ],
    [ "getSize", "class_ogre_1_1_terrain.html#aa23d586fa8023d7992107388bec2d0bd", null ],
    [ "setSize", "class_ogre_1_1_terrain.html#a94a15b828bc003a3bc6a019c9fbbd2ff", null ],
    [ "getMaxBatchSize", "class_ogre_1_1_terrain.html#a33059cbc4162471869976806c34038e6", null ],
    [ "getMinBatchSize", "class_ogre_1_1_terrain.html#afdd76575197788ad0da8d138ab289254", null ],
    [ "getWorldSize", "class_ogre_1_1_terrain.html#abf52cde19183386c011d27a3e190cd7a", null ],
    [ "setWorldSize", "class_ogre_1_1_terrain.html#ad807304e85ba44ddb02aa7cbd639ef4b", null ],
    [ "getLayerCount", "class_ogre_1_1_terrain.html#a1b6d6be6683260c79d51cb5d9a8ca6be", null ],
    [ "getLayerDeclaration", "class_ogre_1_1_terrain.html#aaef840fb3b03d299b83077239122b695", null ],
    [ "addLayer", "class_ogre_1_1_terrain.html#a70a42e6eb37cb024b4573fc912e219b4", null ],
    [ "addLayer", "class_ogre_1_1_terrain.html#a1b09422cf8baa9b8dddd45290de9a666", null ],
    [ "removeLayer", "class_ogre_1_1_terrain.html#ae0b3ec5f09b44fdc3b83f0535c2d1a27", null ],
    [ "replaceLayer", "class_ogre_1_1_terrain.html#ae052005afc7eb71b24aef24fc22dd7e0", null ],
    [ "getMaxLayers", "class_ogre_1_1_terrain.html#a891a8c6a16efd6ecf16508e21cade01e", null ],
    [ "getLayerWorldSize", "class_ogre_1_1_terrain.html#a30d2fed380ea0b55b182cccf77670108", null ],
    [ "setLayerWorldSize", "class_ogre_1_1_terrain.html#a4447c7ef2269781192e5b637035b08fc", null ],
    [ "getLayerUVMultiplier", "class_ogre_1_1_terrain.html#ac38fc212b7a4d6a21843518c237cc44d", null ],
    [ "getLayerTextureName", "class_ogre_1_1_terrain.html#acfbf3bcc122a028d53ea35cad9e1eaaa", null ],
    [ "setLayerTextureName", "class_ogre_1_1_terrain.html#af1dc74d66c4f3867a484d09cf2063fbc", null ],
    [ "getLayerBlendMapSize", "class_ogre_1_1_terrain.html#a148549dc9a5d14725b5c44256638e8ad", null ],
    [ "getLightmapSize", "class_ogre_1_1_terrain.html#ae0168de61d9cc2f640d081538ad4ded9", null ],
    [ "getLightmap", "class_ogre_1_1_terrain.html#a6eea690ea25ed524f7c5fdb840b050a9", null ],
    [ "getCompositeMapSize", "class_ogre_1_1_terrain.html#a3740cb23e839b4a98e60c18b559d1309", null ],
    [ "getCompositeMap", "class_ogre_1_1_terrain.html#a21d313fdb0d84c403075a8c05a16940e", null ],
    [ "getPosition", "class_ogre_1_1_terrain.html#aa2ab5629b96f5fd91fec05edca29812a", null ],
    [ "setPosition", "class_ogre_1_1_terrain.html#aa87ddbb08f493d0901594fe6e3f4cafe", null ],
    [ "_getRootSceneNode", "class_ogre_1_1_terrain.html#a199fe8f1cab6aef966eea1b66c9f4b39", null ],
    [ "dirty", "class_ogre_1_1_terrain.html#aab69f3dead87b53b84784c7d7d325f68", null ],
    [ "dirtyRect", "class_ogre_1_1_terrain.html#a0a9de436fad8d6f3a95b1b78314fb736", null ],
    [ "_dirtyCompositeMapRect", "class_ogre_1_1_terrain.html#aa40d40d6f3de43fa0651079673145b95", null ],
    [ "dirtyLightmapRect", "class_ogre_1_1_terrain.html#a0852e0efabe0cbaf49277dbb261a5490", null ],
    [ "dirtyLightmap", "class_ogre_1_1_terrain.html#a9e432dfa8261600759fb020c09c169a1", null ],
    [ "update", "class_ogre_1_1_terrain.html#ae1ebf4ca9e17f173a0d516d92aed411e", null ],
    [ "updateGeometry", "class_ogre_1_1_terrain.html#a8e7fc528309dff0459e1558971a31d00", null ],
    [ "updateGeometryWithoutNotifyNeighbours", "class_ogre_1_1_terrain.html#a6c319d29b618e68b9a8d6dd3b0652dcb", null ],
    [ "updateDerivedData", "class_ogre_1_1_terrain.html#aa11183930beb39da27e84ca66673ef00", null ],
    [ "updateCompositeMap", "class_ogre_1_1_terrain.html#a84b12bda4d87a9145c5b131166275fd3", null ],
    [ "updateCompositeMapWithDelay", "class_ogre_1_1_terrain.html#a5d4659018c697f0a2fae1192f81ede4a", null ],
    [ "getSkirtSize", "class_ogre_1_1_terrain.html#a607e4aebdee75f7d26c279607d819976", null ],
    [ "getNumLodLevels", "class_ogre_1_1_terrain.html#a2edb50f75fb20e41b169c86cbffceadc", null ],
    [ "getNumLodLevelsPerLeaf", "class_ogre_1_1_terrain.html#aeb53dbed1ad2cb6cb22cefefa8039c68", null ],
    [ "calculateHeightDeltas", "class_ogre_1_1_terrain.html#a57b254a77b1c0fe87a34366ab08db4f3", null ],
    [ "finaliseHeightDeltas", "class_ogre_1_1_terrain.html#a1da607007f9aa988b80df8d3036e187e", null ],
    [ "calculateNormals", "class_ogre_1_1_terrain.html#a90f92130d910fa3d1f2acb6870acdec4", null ],
    [ "finaliseNormals", "class_ogre_1_1_terrain.html#a19862c05e3b50f4464a41e48c12c5245", null ],
    [ "calculateLightmap", "class_ogre_1_1_terrain.html#a1d26ac546212deb98d330775aa4c9e01", null ],
    [ "finaliseLightmap", "class_ogre_1_1_terrain.html#a36a0e738c270ab2d804446f3e93ae651", null ],
    [ "getResolutionAtLod", "class_ogre_1_1_terrain.html#afe71e5b01aa9db756587fadb27eb2a83", null ],
    [ "rayIntersects", "class_ogre_1_1_terrain.html#a66f5889d081e8e45d803e3c0abf0a35a", null ],
    [ "getAABB", "class_ogre_1_1_terrain.html#a64429e495a609ecb6f22a23aa3ed4037", null ],
    [ "getWorldAABB", "class_ogre_1_1_terrain.html#ad0f38e00e35fe85b04ed010a27433341", null ],
    [ "getMinHeight", "class_ogre_1_1_terrain.html#a2511163a9389cff84b1dfecdd863b381", null ],
    [ "getMaxHeight", "class_ogre_1_1_terrain.html#a8dc48d60a3f7e6a152b6757baf32c513", null ],
    [ "getBoundingRadius", "class_ogre_1_1_terrain.html#aa250d15148f1cbf87777ff36a628da9e", null ],
    [ "getMaterial", "class_ogre_1_1_terrain.html#aba442116bbed4a35f60b8565ff1c7318", null ],
    [ "_getMaterial", "class_ogre_1_1_terrain.html#ad7dddc1d68a0936b4b07fa7054f042fc", null ],
    [ "getCompositeMapMaterial", "class_ogre_1_1_terrain.html#abde5a9931a278de23697fe6996a0e6d9", null ],
    [ "_getCompositeMapMaterial", "class_ogre_1_1_terrain.html#a53a08891b2dec0febd07bde5680598e7", null ],
    [ "getMaterialName", "class_ogre_1_1_terrain.html#adc32dec06092d0cdf5c89830aa217d41", null ],
    [ "preFindVisibleObjects", "class_ogre_1_1_terrain.html#ac1f87183250b885c01270a68d80236e4", null ],
    [ "sceneManagerDestroyed", "class_ogre_1_1_terrain.html#a5f7edff06d941d5621aad56c7d19c939", null ],
    [ "getRenderQueueGroup", "class_ogre_1_1_terrain.html#a85c8ed1f55d5cf5300e2ccc2d02ab2f5", null ],
    [ "setRenderQueueGroup", "class_ogre_1_1_terrain.html#a9ff521bcc0fb0193d9105af627af5c0d", null ],
    [ "getVisibilityFlags", "class_ogre_1_1_terrain.html#a124354ea9deb52eced5e1d5a75a2b996", null ],
    [ "setVisibilityFlags", "class_ogre_1_1_terrain.html#a03a3ea2ce4dba4e2948a6b9d1fc02566", null ],
    [ "getQueryFlags", "class_ogre_1_1_terrain.html#abbfdc91237fe8c41297f4715e96b1a19", null ],
    [ "setQueryFlags", "class_ogre_1_1_terrain.html#a4b05d2eef470c736f23b6e3dbb5619d9", null ],
    [ "addQueryFlags", "class_ogre_1_1_terrain.html#ad7934e16e9ad7a0a272bb86d46c17b9e", null ],
    [ "removeQueryFlags", "class_ogre_1_1_terrain.html#aa0e26a4fd6e9897509bf7372388427ff", null ],
    [ "getLayerBlendMap", "class_ogre_1_1_terrain.html#a4c17d599a4b63584160403e162a30e39", null ],
    [ "getBlendTextureIndex", "class_ogre_1_1_terrain.html#abea533df30a7cec072f08f527978c095", null ],
    [ "getBlendTextureCount", "class_ogre_1_1_terrain.html#a9167eb4f73df66b86bc63a9aea34bb88", null ],
    [ "getBlendTextureCount", "class_ogre_1_1_terrain.html#afdd34b73ebfbf437789a8ef2a8cf1c54", null ],
    [ "getBlendTextures", "class_ogre_1_1_terrain.html#a1ee7590f6de4fa9a5d51c29e7fe610b3", null ],
    [ "getBlendTextureName", "class_ogre_1_1_terrain.html#ab6c399c76c55b4befe775f9ab2e0c6c7", null ],
    [ "setGlobalColourMapEnabled", "class_ogre_1_1_terrain.html#ac2b0283f89f542552c2e40e07899f95d", null ],
    [ "getGlobalColourMapEnabled", "class_ogre_1_1_terrain.html#aa55c99add54accbfe6542f53b1a34c12", null ],
    [ "getGlobalColourMapSize", "class_ogre_1_1_terrain.html#acd720425368a1c9e9152c01da3e3c3cd", null ],
    [ "getGlobalColourMap", "class_ogre_1_1_terrain.html#a7ec8a99d7ea299a4f13397aa3177cc68", null ],
    [ "widenRectByVector", "class_ogre_1_1_terrain.html#aff2c1091b6355257deabcae1755adec9", null ],
    [ "widenRectByVector", "class_ogre_1_1_terrain.html#a19739da0efce18871375737421846f1c", null ],
    [ "freeTemporaryResources", "class_ogre_1_1_terrain.html#a4ee732f95cf2b3c4aacb709db48fad1e", null ],
    [ "getLayerBlendTexture", "class_ogre_1_1_terrain.html#ae1afa9f6173f69047bdf0beb9906c483", null ],
    [ "getLayerBlendTextureIndex", "class_ogre_1_1_terrain.html#a74f835b3f72cc06589d38d0b6e012650", null ],
    [ "_setMorphRequired", "class_ogre_1_1_terrain.html#a2a65fb835fe22a425107ce43edf43219", null ],
    [ "_getMorphRequired", "class_ogre_1_1_terrain.html#a5c7d3147f12a6765dd39d7eb69587df7", null ],
    [ "_setNormalMapRequired", "class_ogre_1_1_terrain.html#a3dba1853267506fed228c02ea8ecfe16", null ],
    [ "_setLightMapRequired", "class_ogre_1_1_terrain.html#a915121f91285f370bd1a01842991ae03", null ],
    [ "_setCompositeMapRequired", "class_ogre_1_1_terrain.html#a10b9f303b81585c1b51d0c273f03a5dd", null ],
    [ "_getUseVertexCompression", "class_ogre_1_1_terrain.html#a3b379afd3348efd5c8e5a87f0b2d0729", null ],
    [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#aca2087cd57d5c80ccf2e983acddb1887", null ],
    [ "getLODLevelWhenVertexEliminated", "class_ogre_1_1_terrain.html#a2f98ad8c78b6046d4d4f4dcf9d367fae", null ],
    [ "getQuadTree", "class_ogre_1_1_terrain.html#a69e78ec7eab8aece2d20df966f0dce49", null ],
    [ "getTerrainNormalMap", "class_ogre_1_1_terrain.html#aadd272b751be4c855ef9233b7e4cd9ce", null ],
    [ "getNeighbour", "class_ogre_1_1_terrain.html#ae60272e5836071d30036915c13dcc5ec", null ],
    [ "setNeighbour", "class_ogre_1_1_terrain.html#aa0d9b7d033bd0b3c29c13e6151c93bd0", null ],
    [ "getOppositeNeighbour", "class_ogre_1_1_terrain.html#ad90008dc319c694b073fc1e6523e03c2", null ],
    [ "getNeighbourIndex", "class_ogre_1_1_terrain.html#a14e9fbfcb1edd236554880595b02899b", null ],
    [ "notifyNeighbours", "class_ogre_1_1_terrain.html#a9a1c32a11911a0ccea0eda01c86484a9", null ],
    [ "neighbourModified", "class_ogre_1_1_terrain.html#a5baccf626f31854f341910aa4c7c0500", null ],
    [ "raySelectNeighbour", "class_ogre_1_1_terrain.html#afd8906489c367ae1742b548f81b41da3", null ],
    [ "_dumpTextures", "class_ogre_1_1_terrain.html#a1ba82d7fe350ae72a2d748eb4e02b960", null ],
    [ "isDerivedDataUpdateInProgress", "class_ogre_1_1_terrain.html#a518a4dcf0c880eeadc3d0ae6ff4aa5b1", null ],
    [ "convertWorldToTerrainAxes", "class_ogre_1_1_terrain.html#a86553dfa0e4c39018d8ee23f96fe588d", null ],
    [ "convertTerrainToWorldAxes", "class_ogre_1_1_terrain.html#afb9983e073970fa2fa47ede55a7f16f6", null ],
    [ "writeLayerDeclaration", "class_ogre_1_1_terrain.html#a124c278790b4228e7dfe6a06575cf653", null ],
    [ "readLayerDeclaration", "class_ogre_1_1_terrain.html#ac78ab1806379267473d03a57dde9bbb8", null ],
    [ "writeLayerInstanceList", "class_ogre_1_1_terrain.html#a7b01d7b34a6cc4c890a393857276bf42", null ],
    [ "readLayerInstanceList", "class_ogre_1_1_terrain.html#a5ea9b366b0dead6adf4bb63382851a17", null ],
    [ "OGRE_RW_MUTEX", "class_ogre_1_1_terrain.html#a998e0575ce4f0385512363c1c8019047", null ],
    [ "waitForDerivedProcesses", "class_ogre_1_1_terrain.html#a8f8965d9490b13d8b156d57fc061558b", null ],
    [ "increaseLodLevel", "class_ogre_1_1_terrain.html#a6ca2d94a3062b2ae63620ff2b1121b25", null ],
    [ "decreaseLodLevel", "class_ogre_1_1_terrain.html#ac11979818981d2a7c09c1982479932b0", null ],
    [ "getHighestLodPrepared", "class_ogre_1_1_terrain.html#afcf5e4be38a9734b95e2a1578630b17d", null ],
    [ "getHighestLodLoaded", "class_ogre_1_1_terrain.html#a8c4feba3c0ec197a375173e90423e978", null ],
    [ "getTargetLodLevel", "class_ogre_1_1_terrain.html#a768bccd8d43b0b1f5ff5eaa513be60f3", null ],
    [ "TerrainLodManager", "class_ogre_1_1_terrain.html#a305c9e25905898002f056b3227b1ee65", null ],
    [ "TERRAIN_CHUNK_ID", "class_ogre_1_1_terrain.html#ad1b6d65618e1ebc55155214f3b10b337", null ],
    [ "TERRAIN_CHUNK_VERSION", "class_ogre_1_1_terrain.html#afd3641ddf000f3e2ca771408f558131b", null ],
    [ "TERRAIN_MAX_BATCH_SIZE", "class_ogre_1_1_terrain.html#a5c204799a40adae8b01411ec05dbc841", null ],
    [ "TERRAINLAYERDECLARATION_CHUNK_ID", "class_ogre_1_1_terrain.html#ac83d9fa6c4ba65db9c7ad66bbd01b0de", null ],
    [ "TERRAINLAYERDECLARATION_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a14ce718231ed706aec11489fc6843d76", null ],
    [ "TERRAINLAYERSAMPLER_CHUNK_ID", "class_ogre_1_1_terrain.html#a53d1561777a42b20c5aa5a42dd96bf9b", null ],
    [ "TERRAINLAYERSAMPLER_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a369a6d0c5e30874dd103c7089406be6c", null ],
    [ "TERRAINLAYERSAMPLERELEMENT_CHUNK_ID", "class_ogre_1_1_terrain.html#adf20ab502696a7e4acf28dec2ebdd0c7", null ],
    [ "TERRAINLAYERSAMPLERELEMENT_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a6b4dc148f017fbd6441bc81f79fe743d", null ],
    [ "TERRAINLAYERINSTANCE_CHUNK_ID", "class_ogre_1_1_terrain.html#acb18d059e425a9e6f7677d4dfb2d43ee", null ],
    [ "TERRAINLAYERINSTANCE_CHUNK_VERSION", "class_ogre_1_1_terrain.html#ac7837f27d59df9244743172d331e2fb3", null ],
    [ "TERRAINDERIVEDDATA_CHUNK_ID", "class_ogre_1_1_terrain.html#a50efd0b73343b76d8cfae1366cfd1cd0", null ],
    [ "TERRAINDERIVEDDATA_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a935d5fea06bddac979ae56c7fa13d9da", null ],
    [ "TERRAINGENERALINFO_CHUNK_ID", "class_ogre_1_1_terrain.html#a61228d1282e5e503848dab11a2c794fd", null ],
    [ "TERRAINGENERALINFO_CHUNK_VERSION", "class_ogre_1_1_terrain.html#a3786f2f64dbc4a16984a607bfa53dd82", null ],
    [ "LOD_MORPH_CUSTOM_PARAM", "class_ogre_1_1_terrain.html#acc4dccaad096e6d2abb01dd4813b18d5", null ],
    [ "DERIVED_DATA_DELTAS", "class_ogre_1_1_terrain.html#adc4deb8ce09c46f3d6215ea1ff390959", null ],
    [ "DERIVED_DATA_NORMALS", "class_ogre_1_1_terrain.html#a633492f40707af756814bca31f0f35ba", null ],
    [ "DERIVED_DATA_LIGHTMAP", "class_ogre_1_1_terrain.html#a1ebde7f1f98abe26938397f7110c88f3", null ],
    [ "DERIVED_DATA_ALL", "class_ogre_1_1_terrain.html#aaef9ac3a5d1ceed0260a17f93b88d848", null ]
];